@@ -22,6 +22,8 @@
 #define SINK_H
 
 #include "device.h"
+#include <pulse/channelmap.h>
+#include <canberra.h>
 
 namespace QPulseAudio
 {
@@ -30,16 +32,20 @@ class Sink : public Device
 {
     Q_OBJECT
 public:
-    Sink(QObject *parent);
+    explicit Sink(QObject *parent);
+    virtual ~Sink();
 
     void update(const pa_sink_info *info);
-    void setVolume(qint64 volume) Q_DECL_OVERRIDE;
-    void setMuted(bool muted) Q_DECL_OVERRIDE;
-    void setActivePortIndex(quint32 port_index) Q_DECL_OVERRIDE;
-    void setChannelVolume(int channel, qint64 volume) Q_DECL_OVERRIDE;
+    void setVolume(qint64 volume) override;
+    void setMuted(bool muted) override;
+    void setActivePortIndex(quint32 port_index) override;
+    void setChannelVolume(int channel, qint64 volume) override;
 
-    bool isDefault() const Q_DECL_OVERRIDE;
-    void setDefault(bool enable) Q_DECL_OVERRIDE;
+    bool isDefault() const override;
+    void setDefault(bool enable) override;
+
+public Q_SLOTS:
+    void testChannel(const QString &name);
 };
 
 } // QPulseAudio
